@@ -1,7 +1,4 @@
-extern crate custom_error;
 extern crate home;
-extern crate ipgen;
-use custom_error::custom_error;
 
 use serde::Serialize;
 
@@ -57,10 +54,11 @@ pub fn make_config_dir(service_name: &str) -> String {
 
 pub fn clean_config_dir(service_name: &str) {
     let config_dir = make_config_dir(service_name);
-    for f in std::fs::read_dir(config_dir).unwrap() {
+    for f in std::fs::read_dir(&config_dir).unwrap() {
         let f = f.unwrap();
         std::fs::remove_file(f.path()).unwrap();
     }
+    std::fs::remove_dir(config_dir).unwrap();
 }
 
 /// Provides a human-readable name for the service.
@@ -77,21 +75,6 @@ pub fn clean_name(name: &str) -> String {
     result
 }
 
-// Using custom_error mostly for read/write errors
-// Note the use of braces rather than parentheses.
-custom_error! {pub InnisfreeError
-    Io{source: std::io::Error} = "input/output error",
-    // CommandFailure{source: std::process::ExitStatus} = "command failed",
-    SshCommandFailure = "SSH command failed",
-    ServerNotFound = "Server does not exist",
-    CommandFailure{msg: String} = "Local command failed: {}",
-    NetworkError{source: reqwest::Error} = "Network error, check connection",
-    PlatformError = "Platform error, only Linux is supported",
-    Template{source: tera::Error} = "Template generation failed",
-    IpGenError{source: ipgen::Error} = "Failed to generate IP address",
-    Unknown = "unknown error",
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
